@@ -14,7 +14,7 @@ e_bar_ <- function(e, serie, bind = NULL, name = NULL, legend = TRUE, y_index =
     .build_data2(e$x$data[[i]], e$x$mapping$x, serie) -> vector
     
     if(!is.null(bind))
-      vector <- .add_bind2(e$x$data[[i]], vector, bind, i = i)
+      vector <- .add_bind2(e, vector, bind, i = i)
     
     e_serie <- list(data = vector)
     
@@ -759,8 +759,8 @@ e_sankey_ <- function(e, source, target, value, layout = "none", rm_x = TRUE, rm
   
   serie <- list(
     type = "sankey",
-    layout = layout,
-    nodes = nodes,
+    orient = layout,
+    data = nodes,
     links = edges,
     ...
   )
